@@ -1,8 +1,8 @@
 /*
  * enum - seq- and jot-like enumerator
  *
- * Copyright (C) 2010, Jan Hauke Rahm <jhr@debian.org>
- * Copyright (C) 2010, Sebastian Pipping <sping@gentoo.org>
+ * Copyright (C) 2010-2012, Jan Hauke Rahm <jhr@debian.org>
+ * Copyright (C) 2010-2012, Sebastian Pipping <sping@gentoo.org>
  * All rights reserved.
  *
  * Redistribution  and use in source and binary forms, with or without
@@ -240,7 +240,7 @@ static token_type identify_token(const char *arg, setter_value *value) {
 	if (ends_with_x(arg)) {
 		const long int i = strtol(arg, &end, 10);
 		if ((*end == 'x') && (end - arg == (int)strlen(arg) - 1)) {
-			if (i < 1) {
+			if (i < 0) {
 				return TOKEN_ERROR_BAD_COUNT;
 			}
 			value->uint_data = i;
@@ -723,6 +723,7 @@ int parse_parameters(unsigned int original_argc, char **original_argv, scaffoldi
 	int success = 1;
 	int usage_needed = 0;
 	int quit = 0;
+	int previous_error_optind = 1;
 
 	/* Inhibit getopt's own error message for unrecognized options */
 	opterr = 0;
@@ -924,9 +925,14 @@ int parse_parameters(unsigned int original_argc, char **original_argv, scaffoldi
 			break;
 
 		case '?':
-			fprintf(stderr, "ERROR: Unrecognized option \"%s\"\n", original_argv[optind - 1]);
-			success = 0;
-			usage_needed = 1;
+			if (optind > previous_error_optind)
+			{
+				fprintf(stderr, "ERROR: Unrecognized option \"%s\"\n", original_argv[optind - 1]);
+				success = 0;
+				usage_needed = 1;
+
+				previous_error_optind = optind;
+			}
 			break;
 
 		default:
@@ -1116,8 +1122,9 @@ int parse_args(unsigned int reduced_argc, char **reduced_argv, scaffolding *dest
 	token_details const use_case_17[] = {DOTDOT, RIGHT};
 	token_details const use_case_18[] = {COUNT};
 	token_details const use_case_19[] = {LEFT, COUNT, RIGHT};
+	token_details const use_case_20[] = {COUNT, DOTDOT, RIGHT};
 
-	use_case table[20];
+	use_case table[21];
 	/* incrementing use_case_NN, random support (bool) */
 	INSTALL_USE_CASE( 0, 1)
 	INSTALL_USE_CASE( 1, 1)
@@ -1139,6 +1146,7 @@ int parse_args(unsigned int reduced_argc, char **reduced_argv, scaffolding *dest
 	INSTALL_USE_CASE(17, 1)
 	INSTALL_USE_CASE(18, 0)
 	INSTALL_USE_CASE(19, 1)
+	INSTALL_USE_CASE(20, 1)
 
 	/* Any arguments given? */
 	if (reduced_argc == 0) {
